@@ -48,6 +48,7 @@ class BasicConfig:
     DB_FILE = 'autosubmit.db'
     AS_TIMES_DB = 'as_times.db'
     DB_PATH = os.path.join(DB_DIR, DB_FILE)
+    ALLOWED_CLIENTS = set(['https://earth.bsc.es/'])
     LOCAL_ROOT_DIR = DB_DIR
     LOCAL_TMP_DIR = 'tmp'
     LOCAL_ASLOG_DIR = 'ASLOGS'
@@ -158,8 +159,9 @@ class BasicConfig:
         if parser.has_option('historiclog', 'path'):
             BasicConfig.HISTORICAL_LOG_DIR = parser.get('historiclog', 'path')
         if parser.has_option('autosubmitapi', 'url'):
-            BasicConfig.AUTOSUBMIT_API_URL = parser.get(
-                'autosubmitapi', 'url')
+            BasicConfig.AUTOSUBMIT_API_URL = parser.get('autosubmitapi', 'url')
+        if parser.has_option('clients', 'authorized'):
+            BasicConfig.ALLOWED_CLIENTS = set(parser.get('clients', 'authorized').split())
 
     @staticmethod
     def read():
